@@ -1,9 +1,8 @@
 from __future__ import annotations
 
-from datetime import datetime
+from datetime import UTC, datetime
 from typing import TYPE_CHECKING, cast
 
-import pytz
 from asgiref.sync import sync_to_async
 from sqlalchemy.dialects.postgresql import insert
 from sqlalchemy.sql.expression import and_
@@ -26,7 +25,7 @@ class GuildsService:
         values = {
             "xid": guild.id,
             "name": name,
-            "updated_at": datetime.now(tz=pytz.utc),
+            "updated_at": datetime.now(tz=UTC),
         }
         upsert = insert(Guild).values(**values)
         upsert = upsert.on_conflict_do_update(
@@ -53,7 +52,7 @@ class GuildsService:
         values = {
             "xid": xid,
             "name": "Unknown Guild",
-            "updated_at": datetime.now(tz=pytz.utc),
+            "updated_at": datetime.now(tz=UTC),
             "banned": banned,
         }
         upsert = insert(Guild).values(**values)
@@ -82,12 +81,18 @@ class GuildsService:
     @sync_to_async()
     def should_voice_create(self) -> bool:
         assert self.guild
-        return cast(bool, self.guild.voice_create)
+        return cast("bool", self.guild.voice_create)
 
     @sync_to_async()
     def get_use_max_bitrate(self) -> bool:
         assert self.guild
-        return cast(bool, self.guild.use_max_bitrate)
+        return cast("bool", self.guild.use_max_bitrate)
+
+    @sync_to_async()
+    def set_suggest_vc_category(self, category: str | None) -> None:
+        assert self.guild
+        self.guild.suggest_voice_category = category
+        DatabaseSession.commit()
 
     @sync_to_async()
     def set_motd(self, message: str | None = None) -> None:
@@ -108,6 +113,8 @@ class GuildsService:
     def toggle_voice_create(self) -> None:
         assert self.guild
         self.guild.voice_create = not self.guild.voice_create
+        if self.guild.voice_create:
+            self.guild.suggest_voice_category = None
         DatabaseSession.commit()
 
     @sync_to_async()
@@ -119,7 +126,7 @@ class GuildsService:
     @sync_to_async()
     def current_name(self) -> str:
         assert self.guild
-        return cast(str | None, self.guild.name) or ""
+        return cast("str | None", self.guild.name) or ""
 
     @sync_to_async()
     def voice_category_prefixes(self) -> list[str]:
@@ -188,7 +195,14 @@ class GuildsService:
     @sync_to_async()
     def award_delete(self, guild_award_id: int) -> None:
         assert self.guild
-        award = DatabaseSession.query(GuildAward).get(guild_award_id)
+        award = DatabaseSession.get(GuildAward, guild_award_id)
         if award:
             DatabaseSession.delete(award)
         DatabaseSession.commit()
+
+    @sync_to_async()
+    def setup_mythic_track(self) -> bool:
+        assert self.guild
+        self.guild.enable_mythic_track = not self.guild.enable_mythic_track
+        DatabaseSession.commit()
+        return self.guild.enable_mythic_track
