@@ -1,9 +1,8 @@
 from __future__ import annotations
 
-import datetime
+from datetime import UTC, datetime
 from typing import Any
 
-import pytz
 from asgiref.sync import sync_to_async
 from dateutil import tz
 from dateutil.relativedelta import relativedelta
@@ -144,6 +143,24 @@ def decomposed(combined_data: list[dict[str, Any]]) -> list[dict[str, Any]]:
 
 
 class PlaysService:
+    @sync_to_async()
+    def get_plays_by_game_id(self, game_id: int) -> list[Play]:
+        return DatabaseSession.query(Play).filter(Play.game_id == game_id).all()
+
+    @sync_to_async()
+    def verify_game_pin(self, *, game_id: int, user_xid: int, guild_xid: int, pin: str) -> bool:
+        filters = [
+            Play.game_id == game_id,
+            Play.user_xid == user_xid,
+            Play.og_guild_xid == guild_xid,
+            Play.pin == pin,
+        ]
+        if not (play := DatabaseSession.query(Play).filter(and_(*filters)).one_or_none()):
+            return False
+        play.verified_at = datetime.now(tz=UTC)
+        DatabaseSession.commit()
+        return True
+
     @sync_to_async()
     def count(self, user_xid: int, guild_xid: int) -> int:
         return int(
@@ -249,7 +266,7 @@ class PlaysService:
             Game.channel_xid == channel_xid,
         ]
         if monthly:
-            target = datetime.datetime.now(tz=pytz.utc).date() + relativedelta(months=-ago)
+            target = datetime.now(tz=UTC).date() + relativedelta(months=-ago)
             filters.append(extract("year", Game.started_at) == target.year)
             filters.append(extract("month", Game.started_at) == target.month)
         result = (
